@@ -49,6 +49,9 @@ def format_datetime(dt):
         elif re.match(pattern2, dt):
             dtformat = datetime.datetime.strptime(dt, '%Y-%m-%d')
             ret = datetime.datetime.strftime(dtformat, '%Y-%m-%d %H:%M:%S')
+        elif '+0800' in dt:
+            dtformat = datetime.strptime(dt, '%a %b %d %H:%M:%S +0800 %Y')
+            ret = datetime.datetime.strftime(dtformat, '%Y-%m-%d %H:%M:%S')
         else:
             ret = dt
     except Exception as e:
